@@ -88,7 +88,6 @@ format_value.logical <- format_value.numeric
 
 
 
-#' @importFrom stats na.omit
 .format_value_unless_integer <- function(x, digits = 2, .missing = "", .width = NULL, .as_percent = FALSE, .zap_small = FALSE, ...) {
   if (is.numeric(x) && !all(.is.int(stats::na.omit(x)))) {
     .format_value(x, digits = digits, .missing = .missing, .width = .width, .as_percent = .as_percent, .zap_small = .zap_small)
@@ -107,12 +106,15 @@ format_value.logical <- format_value.numeric
 
   if (is.numeric(x)) {
     if (isTRUE(.as_percent)) {
-      need_sci <- (abs(100 * x) >= 1e+5 | (log10(abs(100 * x)) < -digits) & !.zap_small) & x != 0
-      x <- ifelse(is.na(x), .missing,
-        ifelse(need_sci, sprintf("%.*e%%", digits, 100 * x),
-          sprintf("%.*f%%", digits, 100 * x)
-        )
-      )
+      need_sci <- (abs(100 * x) >= 1e+5 | (log10(abs(100 * x)) < -digits)) & x != 0
+      if (.zap_small) {
+        x <- ifelse(is.na(x), .missing, sprintf("%.*f%%", digits, 100 * x))
+      } else {
+        x <- ifelse(is.na(x), .missing,
+               ifelse(need_sci,
+                      sprintf("%.*e%%", digits, 100 * x),
+                      sprintf("%.*f%%", digits, 100 * x)))
+      }
     } else {
       if (is.character(digits) && grepl("^scientific", digits)) {
         digits <- tryCatch(
@@ -128,12 +130,15 @@ format_value.logical <- format_value.numeric
         }
         x <- sprintf("%.*e", digits, x)
       } else {
-        need_sci <- (abs(x) >= 1e+5 | (log10(abs(x)) < -digits) & !.zap_small) & x != 0
-        x <- ifelse(is.na(x), .missing,
-                    ifelse(need_sci, sprintf("%.*e", digits, x),
-                           sprintf("%.*f", digits, x)
-                    )
-        )
+        need_sci <- (abs(x) >= 1e+5 | (log10(abs(x)) < -digits)) & x != 0
+        if (.zap_small) {
+          x <- ifelse(is.na(x), .missing, sprintf("%.*f", digits, x))
+        } else {
+          x <- ifelse(is.na(x), .missing,
+                 ifelse(need_sci,
+                        sprintf("%.*e", digits, x),
+                        sprintf("%.*f", digits, x)))
+        }
       }
     }
   } else if (anyNA(x)) {
@@ -180,3 +185,8 @@ format_value.logical <- format_value.numeric
     }
   )
 }
+
+
+.is.fraction <- function(x) {
+  !all(.is.int(x)) && is.numeric(x) && .n_unique(x) > 2
+}
