@@ -67,9 +67,10 @@
 #'   bayestestR::reshape_ci(ci_vals)
 #'
 #'   ci_vals <- get_predicted_ci(x,
-#'                               predictions,
-#'                               dispersion_function = "MAD",
-#'                               interval_function = "HDI")
+#'     predictions,
+#'     dispersion_function = "MAD",
+#'     interval_function = "HDI"
+#'   )
 #'   head(ci_vals)
 #' }
 #'
@@ -81,7 +82,6 @@
 #' head(ci_vals)
 #' ci_vals <- get_predicted_ci(x, predictions, ci_type = "confidence")
 #' head(ci_vals)
-#' @importFrom stats median sd quantile
 #' @export
 get_predicted_ci <- function(x,
                              predictions = NULL,
@@ -106,7 +106,7 @@ get_predicted_ci <- function(x,
   }
 
   # Analytical solution
-  if (ci_type == "confidence" || get_family(x)$family %in% c("gaussian")) {# gaussian or CI
+  if (ci_type == "confidence" || get_family(x)$family %in% c("gaussian")) { # gaussian or CI
     se <- .get_predicted_ci_se(x, predictions, data = data, ci_type = ci_type, vcov_estimation = vcov_estimation, vcov_type = vcov_type, vcov_args = vcov_args)
     return(.get_predicted_se_to_ci(x, predictions, se = se, ci = ci))
   } else {
@@ -163,14 +163,13 @@ get_predicted_ci <- function(x,
 # Get Model matrix ------------------------------------------------------------
 
 
-#' @importFrom stats model.matrix terms reformulate
 .get_predicted_ci_modelmatrix <- function(x, data = NULL, vcovmat = NULL, ...) {
   resp <- find_response(x)
   if (is.null(vcovmat)) vcovmat <- .get_predicted_ci_vcov(x, ...)
 
 
   if (is.null(data)) {
-    mm <- stats::model.matrix(x)
+    mm <- get_modelmatrix(x)
   } else {
     if (!all(resp %in% data)) data[[resp]] <- 0 # fake response
     # else, model.matrix below fails, e.g. for log-terms
@@ -202,8 +201,14 @@ get_predicted_ci <- function(x,
         model_terms <- stats::reformulate(all_terms[!off_terms], response = find_response(x))
       }
     }
-    mm <- stats::model.matrix(model_terms, data = data)
+    mm <- get_modelmatrix(model_terms, data = data)
   }
+
+  # fix rank deficiency
+  if (ncol(vcovmat) < ncol(mm)) {
+    mm <- mm[, intersect(colnames(mm), colnames(vcovmat))]
+  }
+
   mm
 }
 
@@ -254,7 +259,6 @@ get_predicted_ci <- function(x,
 
 
 
-#' @importFrom stats qnorm qt
 .get_predicted_se_to_ci <- function(x, predictions = NULL, se = NULL, ci = 0.95) {
 
   # TODO: Prediction interval for binomial: https://fromthebottomoftheheap.net/2017/05/01/glm-prediction-intervals-i/
@@ -284,6 +288,18 @@ get_predicted_ci <- function(x,
       crit_val <- stats::qt(p = (1 + ci) / 2, df = dof)
     }
 
+    if (length(predictions) != length(se)) {
+      # multiple length?
+      if (length(predictions) %% length(se) == 0) {
+        # for multiple length, SE and predictions may match, could be intended?
+        # could there be any cases where we have twice or x times the length of
+        # predictions as standard errors?
+        warning(format_message("Predictions and standard errors are not of the same length. Please check if you need the 'data' argument."), call. = FALSE)
+      } else {
+        stop(format_message("Predictions and standard errors are not of the same length. Please specify the 'data' argument."), call. = FALSE)
+      }
+    }
+
     ci_low <- predictions - (se * crit_val)
     ci_high <- predictions + (se * crit_val)
   }
@@ -295,9 +311,7 @@ get_predicted_ci <- function(x,
 
 # Get PI ------------------------------------------------------------------
 
-#' @importFrom stats qbinom qpois
-.get_predicted_pi_glm <- function(x, predictions, ci = ci) {
-
+.get_predicted_pi_glm <- function(x, predictions, ci = 0.95) {
   info <- model_info(x)
   linkfun <- link_function(x)
   linkinv <- link_inverse(x)
@@ -323,9 +337,8 @@ get_predicted_ci <- function(x,
 
 # Interval helpers --------------------------------------------------------
 
-#' @importFrom stats sd mad
 .get_predicted_se_from_iter <- function(iter, dispersion_function = "SD") {
-  data <- as.data.frame(t(iter))  # Reshape
+  data <- as.data.frame(t(iter)) # Reshape
 
   # Dispersion
   if (is.character(dispersion_function)) {
@@ -334,7 +347,7 @@ get_predicted_ci <- function(x,
       se <- apply(data, 2, stats::sd)
     } else if (dispersion_function == "mad") {
       se <- apply(data, 2, stats::mad)
-    } else{
+    } else {
       stop("`dispersion_function` argument not recognized.")
     }
   } else {
@@ -345,7 +358,6 @@ get_predicted_ci <- function(x,
 
 
 
-#' @importFrom stats quantile
 .get_predicted_interval_from_iter <- function(iter, ci = 0.95, interval_function = "quantile") {
 
   # Interval
@@ -367,7 +379,6 @@ get_predicted_ci <- function(x,
     }
     out <- as.data.frame(bayestestR::ci(as.data.frame(t(iter)), ci = ci, method = interval_function))
     if (length(ci) > 1) out <- reshape_ci(out)
-
   }
   out$Parameter <- out$CI <- NULL
   row.names(out) <- NULL
