@@ -35,7 +35,6 @@ get_residuals <- function(x, ...) {
 
 
 #' @rdname get_residuals
-#' @importFrom stats predict residuals fitted
 #' @export
 get_residuals.default <- function(x, weighted = FALSE, verbose = TRUE, ...) {
 
@@ -89,7 +88,7 @@ get_residuals.default <- function(x, weighted = FALSE, verbose = TRUE, ...) {
       {
         yield_warning <- no_response_resid && verbose
         pred <- stats::predict(x, type = "response")
-        observed <- .factor_to_numeric(get_response(x))
+        observed <- .factor_to_numeric(get_response(x, verbose = FALSE))
         observed - pred
       },
       error = function(e) {
@@ -103,7 +102,7 @@ get_residuals.default <- function(x, weighted = FALSE, verbose = TRUE, ...) {
       {
         yield_warning <- no_response_resid && verbose
         pred <- stats::fitted(x)
-        observed <- .factor_to_numeric(get_response(x))
+        observed <- .factor_to_numeric(get_response(x, verbose = FALSE))
         observed - pred
       },
       error = function(e) {
@@ -116,7 +115,7 @@ get_residuals.default <- function(x, weighted = FALSE, verbose = TRUE, ...) {
     if (verbose) warning("Can't extract residuals from model.")
     res <- NULL
   } else if (yield_warning) {
-    warning(paste0("Can't extract '", res_type, "' residuals. Returning response residuals."), call. = FALSE)
+    warning(format_message(paste0("Can't extract '", res_type, "' residuals. Returning response residuals.")), call. = FALSE)
   }
 
   res
@@ -162,7 +161,6 @@ get_residuals.crr <- function(x, weighted = FALSE, verbose = TRUE, ...) {
 
 
 
-#' @importFrom utils capture.output
 #' @export
 get_residuals.slm <- function(x, weighted = FALSE, verbose = TRUE, ...) {
   if (isTRUE(weighted)) {
@@ -195,8 +193,8 @@ get_residuals.slm <- function(x, weighted = FALSE, verbose = TRUE, ...) {
   w <- get_weights(x, null_as_ones = TRUE)
   tryCatch(
     {
-      res_resp <- as.vector(get_residuals(x, weighted = FALSE, type = "response", verbose = verbose))
-      res_dev <- as.vector(get_residuals(x, weighted = FALSE, type = "deviance", verbose = verbose))
+      res_resp <- as.vector(get_residuals(x, weighted = FALSE, type = "response", verbose = FALSE))
+      res_dev <- as.vector(get_residuals(x, weighted = FALSE, type = "deviance", verbose = FALSE))
 
       if (!is.null(w) && !is.null(res_dev) && !all(w == 1)) {
         if (!is.null(res_resp) && identical(res_resp, res_dev)) {
@@ -205,9 +203,9 @@ get_residuals.slm <- function(x, weighted = FALSE, verbose = TRUE, ...) {
         res_dev <- res_dev[!is.na(w) & w != 0]
       } else if (verbose) {
         if (is.null(w)) {
-          warning("Can't calculate weighted residuals from model. Model doesn't seem to have weights.", call. = FALSE)
+          warning(format_message("Can't calculate weighted residuals from model. Model doesn't seem to have weights."), call. = FALSE)
         } else if (is.null(res_dev)) {
-          warning("Can't calculate weighted residuals from model. Could not extract deviance-residuals.", call. = FALSE)
+          warning(format_message("Can't calculate weighted residuals from model. Could not extract deviance-residuals."), call. = FALSE)
         }
       }
       res_dev
