@@ -22,7 +22,6 @@
 #' link_inverse(m)(.3)
 #' # same as
 #' exp(.3)
-#' @importFrom stats family make.link gaussian formula
 #' @export
 link_inverse <- function(x, ...) {
   UseMethod("link_inverse")
@@ -56,11 +55,6 @@ link_inverse.default <- function(x, ...) {
 
 
 
-
-
-
-
-
 # GLM families ---------------------------------------------------
 
 
@@ -84,13 +78,6 @@ link_inverse.bigglm <- link_inverse.glm
 
 
 
-
-
-
-
-
-
-
 # Tobit Family ---------------------------------
 
 
@@ -115,14 +102,8 @@ link_inverse.flexsurvreg <- function(x, ...) {
 }
 
 
-
-
-
-
-
 # Gaussian identity links ---------------------------------
 
-
 #' @export
 link_inverse.lm <- function(x, ...) {
   stats::gaussian(link = "identity")$linkinv
@@ -209,6 +190,10 @@ link_inverse.complmrob <- link_inverse.lm
 #' @export
 link_inverse.speedlm <- link_inverse.lm
 
+#' @export
+link_inverse.afex_aov <- link_inverse.lm
+
+
 
 
 #' @rdname link_inverse
@@ -305,6 +290,14 @@ link_inverse.ivprobit <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.mvord <- function(x, ...) {
+  link_name <- x$rho$link$name
+  l <- stats::make.link(link = ifelse(link_name == "mvprobit", "probit", "logit"))
+  l$linkinv
+}
+
+
 
 
 
@@ -746,7 +739,6 @@ link_inverse.mira <- function(x, ...) {
 }
 
 
-#' @importFrom stats poisson
 .get_cplm_family <- function(x) {
   link <- parse(text = .safe_deparse(x@call))[[1]]$link
 
