@@ -1,9 +1,8 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-if (.runThisTest || Sys.getenv("USER") == "travis") {
+if (.runThisTest) {
   if (require("testthat") &&
     require("insight") && require("glmmTMB") && require("biglm")) {
-
     data(Salamanders)
     Salamanders$cover <- abs(Salamanders$cover)
 
