@@ -8,6 +8,12 @@ if (require("testthat") &&
   test_that("model_info", {
     expect_true(model_info(m1)$is_poisson)
     expect_true(model_info(m1)$is_zero_inflated)
+    expect_false(model_info(m1)$is_linear)
+  })
+
+  test_that("n_parameters", {
+    expect_equal(n_parameters(m1), 8)
+    expect_equal(n_parameters(m1, component = "conditional"), 5)
   })
 
   test_that("find_predictors", {
@@ -48,7 +54,8 @@ if (require("testthat") &&
       list(
         conditional = as.formula("art ~ fem + mar + kid5 + ment"),
         zero_inflated = as.formula("~kid5 + phd")
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
